@@ -3,7 +3,7 @@
 import fastapi
 
 # custom
-from sunwaee.aegen._api._router import aegen_router
+from sunwaee.gen._api._router import aegen_router
 
 app = fastapi.FastAPI(
     title="Sunwæe API",
