@@ -3,7 +3,7 @@
 import typer
 
 # custom
-from sunwaee.aegen._cli._entrypoint import aegen_commands
+from sunwaee.gen._cli._entrypoint import aegen_commands
 
 cli_app = typer.Typer(
     name="sunwaee",
@@ -16,4 +16,4 @@ def main():
     cli_app()
 
 
-cli_app.add_typer(aegen_commands, name="aegen")
+cli_app.add_typer(aegen_commands, name="gen")
